@@ -352,12 +352,16 @@
 #define __NR_pkey_mprotect	394
 #define __NR_pkey_alloc	395
 #define __NR_pkey_free	396
+#define __NR_statx	397
+#define __NR_rseq	398
+#define __NR_io_pgetevents	399
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
 #define __ARM_NR_usr26		0x0f0003
 #define __ARM_NR_usr32		0x0f0004
 #define __ARM_NR_set_tls	0x0f0005
+#define __ARM_NR_get_tls	0x0f0006
 
 #define SYS_restart_syscall	0
 #define SYS_exit	1
@@ -713,3 +717,6 @@
 #define SYS_pkey_mprotect	394
 #define SYS_pkey_alloc	395
 #define SYS_pkey_free	396
+#define SYS_statx	397
+#define SYS_rseq	398
+#define SYS_io_pgetevents	399
